LTR559 Proximity/Presence/Light Sensor
======================================

|Build Status| |Coverage Status| |PyPi Package| |Python Versions|

Suitable for detecting proximity of an object at close range the LTR559
is great for approach detection and ambient light compensation. The
range is useful to around 2cm, and this is the type of sensor you might
find in a smartphone to determine if you're holding it against your
head.

Installing
==========

Stable library from PyPi:

-  Just run ``sudo pip install ltr559``

Latest/development library from GitHub:

-  ``git clone https://github.com/pimoroni/ltr559-python``
-  ``cd ltr559-python``
-  ``sudo ./install.sh``

.. |Build Status| image:: https://travis-ci.com/pimoroni/ltr559-python.svg?branch=master
   :target: https://travis-ci.com/pimoroni/ltr559-python
.. |Coverage Status| image:: https://coveralls.io/repos/github/pimoroni/ltr559-python/badge.svg?branch=master
   :target: https://coveralls.io/github/pimoroni/ltr559-python?branch=master
.. |PyPi Package| image:: https://img.shields.io/pypi/v/ltr559.svg
   :target: https://pypi.python.org/pypi/ltr559-python
.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/ltr559.svg
   :target: https://pypi.python.org/pypi/ltr559-python
